Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2973)

Unified Diff: chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_browser.h

Issue 11451019: Remove TabContents from ui/ash. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_browser.h
diff --git a/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_browser.h b/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_browser.h
index f6b12bda698550a05814a20147c7cce00c0139a4..2fff758899f341519215296f640c2f72c70a6f0a 100644
--- a/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_browser.h
+++ b/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_browser.h
@@ -32,7 +32,6 @@ class BrowserLauncherItemControllerTest;
class LauncherItemController;
class Profile;
class ShellWindowLauncherController;
-class TabContents;
namespace ash {
class LauncherModel;
@@ -206,7 +205,7 @@ class ChromeLauncherControllerPerBrowser
aura::RootWindow* root_window) OVERRIDE;
// The tab no longer represents its previously identified application.
- virtual void RemoveTabFromRunningApp(TabContents* tab,
+ virtual void RemoveTabFromRunningApp(content::WebContents* tab,
const std::string& app_id) OVERRIDE;
// Notify the controller that the state of an non platform app's tabs
@@ -276,9 +275,9 @@ class ChromeLauncherControllerPerBrowser
typedef std::map<ash::LauncherID, LauncherItemController*>
IDToItemControllerMap;
- typedef std::list<TabContents*> TabContentsList;
- typedef std::map<std::string, TabContentsList> AppIDToTabContentsListMap;
- typedef std::map<TabContents*, std::string> TabContentsToAppIDMap;
+ typedef std::list<content::WebContents*> WebContentsList;
+ typedef std::map<std::string, WebContentsList> AppIDToWebContentsListMap;
+ typedef std::map<content::WebContents*, std::string> WebContentsToAppIDMap;
// Returns the profile used for new windows.
Profile* GetProfileForNewWindows();
@@ -304,8 +303,8 @@ class ChromeLauncherControllerPerBrowser
// Sets the shelf alignment from prefs.
void SetShelfAlignmentFromPrefs();
- // Returns the most recently active tab contents for an app.
- TabContents* GetLastActiveTabContents(const std::string& app_id);
+ // Returns the most recently active WebContents for an app.
+ content::WebContents* GetLastActiveWebContents(const std::string& app_id);
// Creates an app launcher to insert at |index|. Note that |index| may be
// adjusted by the model to meet ordering constraints.
@@ -325,11 +324,11 @@ class ChromeLauncherControllerPerBrowser
IDToItemControllerMap id_to_item_controller_map_;
- // Maintains activation order of tab contents for each app.
- AppIDToTabContentsListMap app_id_to_tab_contents_list_;
+ // Maintains activation order of web contents for each app.
+ AppIDToWebContentsListMap app_id_to_web_contents_list_;
- // Direct access to app_id for a tab contents.
- TabContentsToAppIDMap tab_contents_to_app_id_;
+ // Direct access to app_id for a web contents.
+ WebContentsToAppIDMap web_contents_to_app_id_;
// Used to track shell windows.
scoped_ptr<ShellWindowLauncherController> shell_window_controller_;

Powered by Google App Engine
This is Rietveld 408576698